/**************************************************************************
/* This class shows how to query image-parameters
/* (see identify(1) from the ImageMagick-toolkit)
/*
/* Copyright (c) 2003 by Bernhard Bablok (mail@bablokb.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/

import magick.*;
import java.awt.*;

/**
   This class shows how to query image-parameters
   (see identify(1) from the ImageMagick-toolkit).

   @version $Revision: 1.1 $
   @author  $Author: Bablokb $
*/

public class Identify {

  //////////////////////////////////////////////////////////////////////////////

  public static void usage() {
    System.out.println("usage: java Identify filename [...]");
    System.exit(1);
  }

  //////////////////////////////////////////////////////////////////////////////

  public static void main(String[] args) {
    if (args.length < 1 )
      usage();

    try {
      for (int i=0; i<args.length; ++i) {

	ImageInfo info = new ImageInfo(args[i]);
	MagickImage image = new MagickImage(info);

	System.out.println("Filename: " + image.getFileName());
	System.out.println("  Type: " + image.getMagick());
	Dimension dim = image.getDimension();
	System.out.println("  Width: " + dim.getWidth());
	System.out.println("  Height: " + dim.getHeight());
	System.out.println("  Resolution units: " + image.getUnits());
	System.out.println("  X resolution: " + image.getXResolution());
	System.out.println("  Y resolution: " + image.getYResolution());
	System.out.println("  Size blob: " + image.sizeBlob());
	System.out.println("  Colors: " + image.getNumberColors());
	System.out.println("  Depth: " + image.getDepth());
	System.out.println("  Colorspace: " + image.getColorspace());
	try {
	  image.getColormap();
	  System.out.println("  Colors in colormap: " + image.getColors());
	} catch (MagickException e) {
	}
      }
    } catch (MagickException ex) {
      System.err.println("MagickException: " + ex);
    }
  }

}
